@@ -145,12 +145,12 @@ class RkiCovidParser:
             assert _vaccinations_total in row
             assert _people_first_total in row
             assert _people_full_total in row
-            assert(row[_code] in VaccinationCode2StateMap)
-            state = VaccinationCode2StateMap[row[_code]]
-            #assert state in self.states
-            self.states[state].vaccinationTotal = int(row[_vaccinations_total])
-            self.states[state].vaccinationFirst = int(row[_people_first_total])
-            self.states[state].vaccinationFull = int(row[_people_full_total])
+
+            if row[_code] in VaccinationCode2StateMap:
+                state = VaccinationCode2StateMap[row[_code]]
+                self.states[state].vaccinationTotal = int(row[_vaccinations_total])
+                self.states[state].vaccinationFirst = int(row[_people_first_total])
+                self.states[state].vaccinationFull = int(row[_people_full_total])
 
     async def _load_from_argcis(self, url: str) -> str:
         response = await self.session.get(url)
